# hash-tg

![pypi version](https://github.com/Pavel-Sushko/hash-tg/actions/workflows/python-publish.yml/badge.svg) ![python application](https://github.com/Pavel-Sushko/hash-tg/actions/workflows/python-app.yml/badge.svg) ![dependency review](https://github.com/Pavel-Sushko/hash-tg/actions/workflows/dependency-review.yml/badge.svg)

hash-tg is a Telegram bot that allows you to perform various operations agains obtained hashes.

## Installation

1. Install package from PyPI:

    ```bash
    pip install hash-tg
    ```

## Contributing

If you'd like to contribute to the project, please follow these steps:

1. Fork the repository.
2. Create a new branch for your changes: `git checkout -b my-new-feature`.
3. Make your changes and commit them: `git commit -am 'Add some feature'`.
4. Push to the branch: `git push origin my-new-feature`.
5. Submit a pull request.

## License

hash-tg is licensed under the [MIT License](https://opensource.org/licenses/MIT). Feel free to use it for personal or commercial use.
